slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPSetConvergenceTest

Specifies how to compute the error estimate used in the convergence test.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPSetConvergenceTest(PEP pep,PEPConv conv)

Logically Collective on pep

### Input Parameters

| pep | - eigensolver context obtained from PEPCreate()
| conv | - the type of convergence test

### Options Database Keys

| -pep_conv_abs | - Sets the absolute convergence test
| -pep_conv_rel | - Sets the convergence test relative to the eigenvalue
| -pep_conv_norm | - Sets the convergence test relative to the matrix norms
| -pep_conv_user | - Selects the user-defined convergence test

### Note

The parameter 'conv' can have one of these values

| PEP_CONV_ABS | - absolute error ||r||
| PEP_CONV_REL | - error relative to the eigenvalue l, ||r||/|l|
| PEP_CONV_NORM | - error relative matrix norms, ||r||/sum_i(l^i*||A_i||)
| PEP_CONV_USER | - function set by PEPSetConvergenceTestFunction()

### See Also

PEPGetConvergenceTest(), PEPSetConvergenceTestFunction(), PEPSetStoppingTest(), PEPConv

### Level

intermediate

### Location

src/pep/interface/pepopts.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages